


#ifndef GDATA_MEDIA_ENUMS_H
#define GDATA_MEDIA_ENUMS_H

#include <glib-object.h>

G_BEGIN_DECLS
/* enumerations from "/usr/src/ports/mingw64-x86_64-libgdata/mingw64-x86_64-libgdata-0.17.8-1.noarch/src/libgdata-0.17.8/gdata/media/gdata-media-content.h" */
GType gdata_media_expression_get_type (void) G_GNUC_CONST;
#define GDATA_TYPE_MEDIA_EXPRESSION (gdata_media_expression_get_type())
GType gdata_media_medium_get_type (void) G_GNUC_CONST;
#define GDATA_TYPE_MEDIA_MEDIUM (gdata_media_medium_get_type())
G_END_DECLS

#endif /* !GDATA_MEDIA_ENUMS_H */



