


#ifndef GDATA_PICASAWEB_ENUMS_H
#define GDATA_PICASAWEB_ENUMS_H

#include <glib-object.h>

G_BEGIN_DECLS
/* enumerations from "/usr/src/ports/mingw64-x86_64-libgdata/mingw64-x86_64-libgdata-0.17.8-1.noarch/src/libgdata-0.17.8/gdata/services/picasaweb/gdata-picasaweb-album.h" */
GType gdata_picasaweb_visibility_get_type (void) G_GNUC_CONST;
#define GDATA_TYPE_PICASAWEB_VISIBILITY (gdata_picasaweb_visibility_get_type())
G_END_DECLS

#endif /* !GDATA_PICASAWEB_ENUMS_H */



